@@ -34,28 +34,28 @@
  *
  * Major version of Unique
  */
-#define UNIQUE_MAJOR_VERSION            (1)
+#define UNIQUE_MAJOR_VERSION            (2)
 
 /**
  * UNIQUE_MINOR_VERSION:
  *
  * Minor version of Unique
  */
-#define UNIQUE_MINOR_VERSION            (1)
+#define UNIQUE_MINOR_VERSION            (90)
 
 /**
  * UNIQUE_MICRO_VERSION:
  *
  * Micro version of Unique
  */
-#define UNIQUE_MICRO_VERSION            (4)
+#define UNIQUE_MICRO_VERSION            (1)
 
 /**
  * UNIQUE_VERSION_S:
  *
  * Unique version as a string
  */
-#define UNIQUE_VERSION_S                "1.1.4"
+#define UNIQUE_VERSION_S                "2.90.1"
 
 /**
  * UNIQUE_VERSION_HEX:
@@ -71,14 +71,14 @@
  *
  * API version
  */
-#define UNIQUE_API_VERSION              (1.0)
+#define UNIQUE_API_VERSION              (3.0)
 
 /**
  * UNIQUE_API_VERSION_S:
  *
  * API version as a string
  */
-#define UNIQUE_API_VERSION_S            "1.0"
+#define UNIQUE_API_VERSION_S            "3.0"
 
 /**
  * UNIQUE_PROTOCOL_VERSION:
@@ -99,7 +99,7 @@
  *
  * Default backend as a string
  */
-#define UNIQUE_DEFAULT_BACKEND_S        "dbus"
+#define UNIQUE_DEFAULT_BACKEND_S        "gdbus"
 
 /**
  * UNIQUE_CHECK_VERSION:
